@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.033';
+our $VERSION   = '0.034';
 
 use Types::Standard 1.008003 -is, -types;
 use Types::TypeTiny qw(ArrayLike HashLike);
@@ -587,7 +587,7 @@ sub _make_package {
 					my $role_qname = $builder->qualify_name(shift(@roles), $opts{prefix});
 					push @processed, $role_qname;
 					no strict 'refs';
-					if ( ! ${"$role_qname\::BUILT"} ) {
+					if ( $role_qname !~ /\?$/ and not ${"$role_qname\::BUILT"} ) {
 						my ($role_dfn) = grep { $_->[0] eq "::$role_qname" } @{$opts{_roles}};
 						$builder->make_role(
 							"::$role_qname",
